@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -14,24 +14,25 @@
 """
 from urllib import quote
 
+from AccessControl.class_init import InitializeClass
 from AccessControl.SecurityInfo import ClassSecurityInfo
-from AccessControl.Role import RoleManager
 from Acquisition import Implicit
-from App.class_init import InitializeClass
 from App.special_dtml import DTMLFile
 from App.special_dtml import HTML
 from DateTime.DateTime import DateTime
 from AccessControl import getSecurityManager
-from AccessControl.Permissions import change_dtml_methods
 from AccessControl.Permissions import view_management_screens
 from AccessControl.Permissions import change_proxy_roles
 from AccessControl.Permissions import view as View
 from AccessControl.Permissions import ftp_access
-from AccessControl.DTML import RestrictedDTML
 from AccessControl.requestmethod import requestmethod
+from AccessControl.tainted import TaintedString
+from DocumentTemplate.permissions import change_dtml_methods
+from DocumentTemplate.security import RestrictedDTML
 from OFS.Cache import Cacheable
 from OFS.History import Historical
 from OFS.History import html_diff
+from OFS.role import RoleManager
 from OFS.SimpleItem import Item_w__name__
 from OFS.ZDOM import ElementWithTitle
 from webdav.Lockable import ResourceLockedError
@@ -69,15 +70,11 @@ class DTMLMethod(RestrictedDTML,
     func_code.co_varnames = 'self', 'REQUEST', 'RESPONSE'
     func_code.co_argcount = 3
 
-    manage_options = (
-        (
-            {'label': 'Edit', 'action': 'manage_main',
-             'help': ('OFSP', 'DTML-DocumentOrMethod_Edit.stx')},
-            {'label': 'View', 'action': '',
-             'help': ('OFSP', 'DTML-DocumentOrMethod_View.stx')},
-            {'label': 'Proxy', 'action': 'manage_proxyForm',
-             'help': ('OFSP', 'DTML-DocumentOrMethod_Proxy.stx')},
-            )
+    manage_options = ((
+        {'label': 'Edit', 'action': 'manage_main'},
+        {'label': 'View', 'action': ''},
+        {'label': 'Proxy', 'action': 'manage_proxyForm'},
+        )
         + Historical.manage_options
         + RoleManager.manage_options
         + Item_w__name__.manage_options
@@ -96,7 +93,7 @@ class DTMLMethod(RestrictedDTML,
     security.declareProtected(View, '__call__')
     def __call__(self, client=None, REQUEST={}, RESPONSE=None, **kw):
         """Render using the given client object
-        
+
         o If client is not passed, we are being called as a sub-template:
           don't do any error propagation.
 
@@ -147,7 +144,7 @@ class DTMLMethod(RestrictedDTML,
                 return result
 
             r = apply(HTML.__call__, (self, client, REQUEST), kw)
-            if type(r) is not type('') or RESPONSE is None:
+            if type(r) is not str or RESPONSE is None:
                 if not self._cache_namespace_keys:
                     self.ZCacheable_set(r)
                 return r
@@ -204,14 +201,12 @@ class DTMLMethod(RestrictedDTML,
 
     security.declareProtected(change_dtml_methods, 'getCacheNamespaceKeys')
     def getCacheNamespaceKeys(self):
-        """ Return the cacheNamespaceKeys.
-        """
+        # Return the cacheNamespaceKeys.
         return self._cache_namespace_keys
 
     security.declareProtected(change_dtml_methods, 'setCacheNamespaceKeys')
     def setCacheNamespaceKeys(self, keys, REQUEST=None):
-        """ Set the list of names looked up to provide a cache key.
-        """
+        # Set the list of names looked up to provide a cache key.
         ks = []
         for key in keys:
             key = str(key).strip()
@@ -287,10 +282,12 @@ class DTMLMethod(RestrictedDTML,
             return self._er(data, title,
                             SUBMIT, dtpref_cols, dtpref_rows, REQUEST)
         if self.wl_isLocked():
-            raise ResourceLockedError('This DTML Method is locked via WebDAV')
+            raise ResourceLockedError('This item is locked via WebDAV')
 
         self.title = str(title)
-        if type(data) is not type(''):
+        if isinstance(data, TaintedString):
+            data = data.quoted()
+        if not isinstance(data, basestring):
             data = data.read()
         self.munge(data)
         self.ZCacheable_invalidate()
@@ -306,7 +303,7 @@ class DTMLMethod(RestrictedDTML,
         if self.wl_isLocked():
             raise ResourceLockedError('This DTML Method is locked via WebDAV')
 
-        if type(file) is not type(''):
+        if type(file) is not str:
             if REQUEST and not file:
                 raise ValueError('No file specified')
             file = file.read()
@@ -357,14 +354,12 @@ class DTMLMethod(RestrictedDTML,
 
     security.declareProtected(view_management_screens, 'PrincipiaSearchSource')
     def PrincipiaSearchSource(self):
-        """ Support for searching - the document's contents are searched.
-        """
+        # Support for searching - the document's contents are searched.
         return self.read()
 
     security.declareProtected(view_management_screens, 'document_src')
     def document_src(self, REQUEST=None, RESPONSE=None):
-        """ Return unprocessed document source.
-        """
+        # Return unprocessed document source.
         if RESPONSE is not None:
             RESPONSE.setHeader('Content-Type', 'text/plain')
         return self.read()
@@ -460,7 +455,7 @@ def addDTMLMethod(self, id, title='', file='', REQUEST=None, submit=None):
     """Add a DTML Method object with the contents of file. If
     'file' is empty, default document text is used.
     """
-    if type(file) is not type(''):
+    if type(file) is not str:
         file = file.read()
     if not file:
         file = default_dm_html
