@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """Object Manager
-
-$Id: ObjectManager.py 107529 2010-01-02 03:43:32Z davisagli $
 """
 
 from cgi import escape
@@ -24,8 +22,11 @@ import marshal
 import os
 import re
 import sys
+from types import NoneType
 
 from AccessControl import ClassSecurityInfo
+from AccessControl.class_init import InitializeClass
+from AccessControl.Permission import getPermissions
 from AccessControl.Permissions import view_management_screens
 from AccessControl.Permissions import access_contents_information
 from AccessControl.Permissions import delete_objects
@@ -35,7 +36,6 @@ from AccessControl import getSecurityManager
 from AccessControl.ZopeSecurityPolicy import getRoles
 from Acquisition import aq_base
 from Acquisition import Implicit
-from App.class_init import InitializeClass
 from App.Common import is_acquired
 from App.config import getConfiguration
 from App.Dialogs import MessageDialog
@@ -152,9 +152,6 @@ class ObjectManager(CopyContainer,
     This class provides core behavior for collections of heterogeneous objects.
     """
 
-    # The claim to implement IContainer has been made during the Zope3
-    # integration project called Five but hasn't been completed in full.
-
     implements(IObjectManager)
 
     security = ClassSecurityInfo()
@@ -174,8 +171,7 @@ class ObjectManager(CopyContainer,
     manage_index_main=DTMLFile('dtml/index_main', globals())
 
     manage_options=(
-        {'label':'Contents', 'action':'manage_main',
-         'help':('OFSP','ObjectManager_Contents.stx')},
+        {'label':'Contents', 'action':'manage_main'},
         )
 
     isAnObjectManager=1
@@ -226,8 +222,9 @@ class ObjectManager(CopyContainer,
         external_candidates.extend(list(_pmt))
 
         # Look at all globally visible meta types.
-        for entry in Products.meta_types:
-            if ( (interfaces is not None) or (entry.get("visibility", None)=="Global") ):
+        for entry in getattr(Products, 'meta_types', ()):
+            if ((interfaces is not None) or
+                (entry.get("visibility", None)=="Global")):
                 external_candidates.append(entry)
 
         # Filter the list of external candidates based on the
@@ -235,7 +232,7 @@ class ObjectManager(CopyContainer,
         if interfaces is None:
             interface_constrained_meta_types = external_candidates
         else:
-            interface_constrained_meta_types = []
+            interface_constrained_meta_types = icmt = []
             for entry in external_candidates:
                 try:
                     eil = entry.get('interfaces',None)
@@ -243,7 +240,7 @@ class ObjectManager(CopyContainer,
                         for ei in eil:
                             for i in interfaces:
                                 if ei is i or ei.extends(i):
-                                    interface_constrained_meta_types.append(entry)
+                                    icmt.append(entry)
                                     raise BreakoutException # only append 1ce
                 except BreakoutException:
                     pass
@@ -266,24 +263,20 @@ class ObjectManager(CopyContainer,
         return meta_types
 
     def _subobject_permissions(self):
-        import Products
-        Products_permissions = getattr(Products, '__ac_permissions__', ())
-        return (Products_permissions +
-                self.aq_acquire('_getProductRegistryData')('ac_permissions')
-                )
+        return getPermissions()
 
     def filtered_meta_types(self, user=None):
         # Return a list of the types for which the user has
         # adequate permission to add that type of object.
-        user=getSecurityManager().getUser()
-        meta_types=[]
+        sm = getSecurityManager()
+        meta_types = []
         if callable(self.all_meta_types):
-            all=self.all_meta_types()
+            all = self.all_meta_types()
         else:
-            all=self.all_meta_types
+            all = self.all_meta_types
         for meta_type in all:
-            if meta_type.has_key('permission'):
-                if user.has_permission(meta_type['permission'],self):
+            if 'permission' in meta_type:
+                if sm.checkPermission(meta_type['permission'], self):
                     meta_types.append(meta_type)
             else:
                 meta_types.append(meta_type)
@@ -308,13 +301,13 @@ class ObjectManager(CopyContainer,
             raise AttributeError, id
         return default
 
+    security.declareProtected(access_contents_information, 'hasObject')
     def hasObject(self, id):
-        """Indicate whether the folder has an item by ID.
-
-        This doesn't try to be more intelligent than _getOb, and doesn't
-        consult _objects (for performance reasons). The common use case
-        is to check that an object does *not* exist.
-        """
+        # Indicate whether the folder has an item by ID.
+        #
+        # This doesn't try to be more intelligent than _getOb, and doesn't
+        # consult _objects (for performance reasons). The common use case
+        # is to check that an object does *not* exist.
         if (id in ('.', '..') or
             id.startswith('_') or
             id.startswith('aq_') or
@@ -420,7 +413,7 @@ class ObjectManager(CopyContainer,
         # If 'spec' is specified, returns objects whose meta_type
         # matches 'spec'.
         if spec is not None:
-            if type(spec)==type('s'):
+            if type(spec) is str:
                 spec=[spec]
             set=[]
             for ob in self._objects:
@@ -445,8 +438,9 @@ class ObjectManager(CopyContainer,
 
     def objectMap(self):
         # Return a tuple of mappings containing subobject meta-data
-        return tuple(map(lambda dict: dict.copy(), self._objects))
+        return tuple(d.copy() for d in self._objects)
 
+    security.declareProtected(access_contents_information, 'objectIds_d')
     def objectIds_d(self, t=None):
         if hasattr(self, '_reserved_names'): n=self._reserved_names
         else: n=()
@@ -457,9 +451,11 @@ class ObjectManager(CopyContainer,
             if id not in n: a(id)
         return r
 
+    security.declareProtected(access_contents_information, 'objectValues_d')
     def objectValues_d(self, t=None):
         return map(self._getOb, self.objectIds_d(t))
 
+    security.declareProtected(access_contents_information, 'objectItems_d')
     def objectItems_d(self, t=None):
         r=[]
         a=r.append
@@ -467,6 +463,7 @@ class ObjectManager(CopyContainer,
         for id in self.objectIds_d(t): a((id, g(id)))
         return r
 
+    security.declareProtected(access_contents_information, 'objectMap_d')
     def objectMap_d(self, t=None):
         if hasattr(self, '_reserved_names'): n=self._reserved_names
         else: n=()
@@ -477,15 +474,15 @@ class ObjectManager(CopyContainer,
             if d['id'] not in n: a(d.copy())
         return r
 
+    security.declareProtected(access_contents_information, 'superValues')
     def superValues(self, t):
         # Return all of the objects of a given type located in
         # this object and containing objects.
-        if type(t)==type('s'): t=(t,)
+        if type(t) is str: t=(t,)
         obj=self
         seen={}
         vals=[]
         relativePhysicalPath = ()
-        have=seen.has_key
         x=0
         while x < 100:
             if not hasattr(obj,'_getOb'): break
@@ -495,7 +492,7 @@ class ObjectManager(CopyContainer,
                     try:
                         id=i['id']
                         physicalPath = relativePhysicalPath + (id,)
-                        if (not have(physicalPath)) and (i['meta_type'] in t):
+                        if (physicalPath not in seen) and (i['meta_type'] in t):
                             vals.append(get(id))
                             seen[physicalPath]=1
                     except: pass
@@ -517,7 +514,7 @@ class ObjectManager(CopyContainer,
 
         The objects specified in 'ids' get deleted.
         """
-        if type(ids) is type(''): ids=[ids]
+        if type(ids) is str: ids=[ids]
         if not ids:
             return MessageDialog(title='No items specified',
                    message='No items were specified!',
@@ -545,6 +542,7 @@ class ObjectManager(CopyContainer,
             return self.manage_main(self, REQUEST, update_menu=1)
 
 
+    security.declareProtected(access_contents_information, 'tpValues')
     def tpValues(self):
         # Return a list of subobjects, used by tree tag.
         r=[]
@@ -702,7 +700,8 @@ class ObjectManager(CopyContainer,
 
             all_files = copy.copy(files)
             for f in files:
-                if hasattr(aq_base(f[1]), 'isPrincipiaFolderish') and f[1].isPrincipiaFolderish:
+                if (hasattr(aq_base(f[1]), 'isPrincipiaFolderish') and
+                    f[1].isPrincipiaFolderish):
                     all_files.extend(findChildren(f[1]))
             files = all_files
 
@@ -710,7 +709,7 @@ class ObjectManager(CopyContainer,
 
         globbing = REQUEST.environ.get('GLOBBING','')
         if globbing :
-            files = filter(lambda x,g=globbing: fnmatch.fnmatch(x[0],g), files)
+            files = [x for x in files if fnmatch.fnmatch(x[0],globbing)]
 
         files.sort()
 
@@ -733,6 +732,7 @@ class ObjectManager(CopyContainer,
                 out=out+((k,stat),)
         return marshal.dumps(out)
 
+    security.declareProtected(ftp_access, 'manage_hasId')
     def manage_hasId(self, REQUEST):
         """ check if the folder has an object with REQUEST['id'] """
 
@@ -772,12 +772,13 @@ class ObjectManager(CopyContainer,
         return self.manage_delObjects(ids=[name])
 
     def __getitem__(self, key):
-        v=self._getOb(key, None)
-        if v is not None: return v
-        if hasattr(self, 'REQUEST'):
-            request=self.REQUEST
+        if key in self:
+            return self._getOb(key, None)
+        request = getattr(self, 'REQUEST', None)
+        if not isinstance(request, (str, NoneType)):
             method=request.get('REQUEST_METHOD', 'GET')
-            if request.maybe_webdav_client and not method in ('GET', 'POST'):
+            if (request.maybe_webdav_client and
+                method not in ('GET', 'POST')):
                 return NullResource(self, key, request).__of__(self)
         raise KeyError, key
 
@@ -798,13 +799,15 @@ class ObjectManager(CopyContainer,
 
     security.declareProtected(access_contents_information, 'get')
     def get(self, key, default=None):
-        return self._getOb(key, default)
+        if key in self:
+            return self._getOb(key, default)
+        return default
 
     security.declareProtected(access_contents_information, 'keys')
     def keys(self):
         return self.objectIds()
 
-    security.declareProtected(access_contents_information, 'get')
+    security.declareProtected(access_contents_information, 'items')
     def items(self):
         return self.objectItems()
 
@@ -823,7 +826,8 @@ def findChildren(obj,dirname=''):
 
     lst = []
     for name, child in obj.objectItems():
-        if hasattr(aq_base(child), 'isPrincipiaFolderish') and child.isPrincipiaFolderish:
+        if (hasattr(aq_base(child), 'isPrincipiaFolderish') and
+            child.isPrincipiaFolderish):
             lst.extend(findChildren(child, dirname + obj.id + '/'))
         else:
             lst.append((dirname + obj.id + "/" + name, child))
